=========
modbus.py
=========

Modbus class
============
.. autoclass:: phox_modbus.modbus.Modbus
    :members:
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

Exceptions
==========
.. autoclass:: phox_modbus.modbus.ModbusError
.. autoclass:: phox_modbus.modbus.SlaveExceptionError
.. autoclass:: phox_modbus.modbus.IllegalRequestError
.. autoclass:: phox_modbus.modbus.MasterReportedError
.. autoclass:: phox_modbus.modbus.NoResponseError
.. autoclass:: phox_modbus.modbus.InvalidResponseError

Exceptions inherited from pyserial
----------------------------------
.. autoclass:: serial.SerialException
.. autoclass:: serial.PortNotOpenError
.. autoclass:: serial.SerialTimeoutException
